module Debate.Arguments.Ancestry.PolyphenolReductio exposing (..)

import Debate.Types exposing (..)


argumentPolyphenolReductio : Argument
argumentPolyphenolReductio =
    { argumentTitle = "Harmful Polyphenol Reductio"
    , propositionTitle = "Genetic modification that removes polyphenols from grass renders grass-fed beef less harmful."
    , propositionSummary = "Summary"
    , proofLink = "https://www.umsu.de/trees/#(~6x~6y(Hx~1Cxy~5Vxy)),(Hp),(Cpg),(Vpg~5Mpg),(Vpg)%7C=(Mpg)"
    , definitionTable =
        [ { definiendum = "H(x)"
          , definiens = "(x) is harmful"
          }
        , { definiendum = "C(x,y)"
          , definiens = "(x) is contained in (y)"
          }
        , { definiendum = "V(x,y)"
          , definiens = "(x) renders (y) harmful"
          }
        , { definiendum = "M(p,g)"
          , definiens = "genetic modification that removes (p) renders (g) less harmful"
          }
        , { definiendum = "x"
          , definiens = "plant defense chemicals"
          }
        , { definiendum = "y"
          , definiens = "food"
          }
        , { definiendum = "p"
          , definiens = "polyphenols from grass"
          }
        , { definiendum = "g"
          , definiens = "grass-fed beef"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If plant defense chemicals are harmful and plant defense chemicals are contained in a food, then plant defense chemicals render the food harmful."
                  , notation = "(∀x∀y(Hx∧Cxy→Vxy))"
                  }
                , { premise = "Polyphenols from grass are harmful."
                  , notation = "(Hp)"
                  }
                , { premise = "Polyphenols from grass are contained in grass-fed beef."
                  , notation = "(Cpg)"
                  }
                , { premise = "If polyphenols from grass render grass-fed beef harmful, then genetic modification that removes polyphenols from grass renders grass-fed beef less harmful."
                  , notation = "(Vpg→Mpg)"
                  }
                , { premise = "Polyphenols from grass render grass-fed beef harmful."
                  , notation = "(Vpg)"
                  }
                ]
          , conclusion = "Therefore, genetic modification that removes polyphenols from grass renders grass-fed beef less harmful."
          , conclusionNotation = "(∴Mpg)"
          }
        ]
    }
