module Debate.Arguments.Gender.TransPeople exposing (..)

import Debate.Types exposing (..)


argumentTransPeople : Argument
argumentTransPeople =
    { argumentTitle = "Argument For Trans Identity"
    , propositionTitle = "A trans person of the male sex is a woman and a trans person with female sex is a man."
    , propositionSummary = "Summary"
    , proofLink = "https://www.umsu.de/trees/#(~6x(Wx~4Lx~1Ox)),(~6x(Mx~4Sx~1Ox)),(La~1Oa),(Sg~1Og)%7C=(Wa~1Mg)"
    , definitionTable =
        [ { definiendum = "Male"
          , definiens = "the cluster of traits that associate with small, but not large, gametes."
          }
        , { definiendum = "Female"
          , definiens = "the cluster of traits that associate with large, but not small, gametes."
          }
        , { definiendum = "W"
          , definiens = "(x) is a woman"
          }
        , { definiendum = "M"
          , definiens = "(x) is a man"
          }
        , { definiendum = "L"
          , definiens = "(x) possesses a sufficiently greater sum of weighted traits that more closely associate with large gametes than weighted traits that associate with small gametes"
          }
        , { definiendum = "S"
          , definiens = "(x) possesses a sufficiently greater sum of weighted traits that more closely associate with small gametes than weighted traits that associate with large gametes"
          }
        , { definiendum = "O"
          , definiens = "(x) is over 18 years of age"
          }
        , { definiendum = "x"
          , definiens = "someone"
          }
          , { definiendum = "a"
          , definiens = "a trans person of the male sex"
          }
          , { definiendum = "g"
          , definiens = "a trans person of the female sex"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "Someone is a woman if, and only if, someone possesses a sufficiently greater sum of weighted traits that more closely associate with large gametes than weighted traits that associate with small gametes and someone is over 18 years of age."
                  , notation = "(∀x(Wx↔Lx∧Ox))"
                  }
                , { premise = "Someone is a man if, and only if, someone possesses a sufficiently greater sum of weighted traits that more closely associate with small gametes than weighted traits that associate with large gametes and someone is over 18 years of age."
                  , notation = "(∀x(Mx↔Sx∧Ox))"
                  }
                , { premise = "A trans person of the male sex possesses a sufficiently greater sum of weighted traits that more closely associate with large gametes than weighted traits that associate with small gametes and a trans person with small gametes is over 18 years of age."
                  , notation = "(La∧Oa)"
                  }
                , { premise = "A trans person of the female sex possesses a sufficiently greater sum of weighted traits that more closely associate with small gametes than weighted traits that associate with large gametes and a trans person with large gametes is over 18 years of age."
                  , notation = "(Sg∧Og)"
                  }
                ]
          , conclusion = "Therefore, a trans person of the male sex is a woman and a trans person with female sex is a man."
          , conclusionNotation = "(∴Wa∧Mg)"
          }
        ]
    }
