module Debate.Arguments.Nutrition.Malondialdehyde exposing (..)

import Debate.Types exposing (..)


argumentMalondialdehyde : Argument
argumentMalondialdehyde =
    { argumentTitle = "Atherogenic Omega-3 Reductio"
    , propositionTitle = "Omega-3s are atherogenic."
    , propositionSummary = "Summary"
    , proofLink = "https://www.umsu.de/trees/#(~6x(Ax~4Lx)),(Lm),(Am~5~6x(Fx))%7C=(Fo)"
    , definitionTable =
        [ { definiendum = "A(x)"
          , definiens = "(x) increases the risk of atherosclerosis"
          }
        , { definiendum = "L(x)"
          , definiens = "(x) facilitates the oxidative modification of LDL particles"
          }
        , { definiendum = "F(x)"
          , definiens = "all (x) are atherogenic"
          }
        , { definiendum = "m"
          , definiens = "malondialdehyde"
          }
        , { definiendum = "o"
          , definiens = "omega-3s"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "Something increases the risk of atherosclerosis if and only if something facilitates the oxidative modification of LDL particles."
                  , notation = "(∀x(Ax↔Lx))"
                  }
                , { premise = "Malondialdehyde facilitates the oxidative modification of LDL particles."
                  , notation = "(Lm)"
                  }
                , { premise = "If malondialdehyde increases the risk of atherosclerosis, then all malondialdehyde-producing fatty acids are atherogenic."
                  , notation = "(Am→∀x(Fx))"
                  }
                ]
          , conclusion = "Therefore, omega-3s are atherogenic."
          , conclusionNotation = "(∴Fo)"
          }
        ]
    }
